riverpod_mutations_annotation library
The annotations and interfaces for riverpod_mutations_generator
Classes
-
Mutation<
ResultT> - Mutations are a form of UI state that represents "side-effects" (such as "submitting a form" or "saving a file", etc).
-
MutationError<
ResultT> - The mutation has failed with an error.
-
MutationIdle<
ResultT> - The mutation is not running.
-
MutationListenable<
ResultT, RunT> -
MutationPairListenable<
ResultT, RunT, PairRunT> -
MutationPending<
ResultT> - The mutation has been called and is in progress.
-
MutationState<
ResultT> - The current state of a mutation.
-
MutationSuccess<
ResultT> - The mutation has completed successfully.
- MutationTarget
- An interface for objects that can be passed to Mutation.run.
- MutationTransaction
- A "ref" to be used within Mutation.run.
-
Provider<
ValueT> Providers - A provider that exposes a read-only value.
Extensions
-
MutationListenableX
on MutationListenable<
ResultT, RunT>
Constants
- mutation → const _Mutation
- mutationKey → const _MutationKey
- mutationPair → const _Mutation